###########################################################################################
#
# clop_forest ver0.02.r - Forest plot for the Clopidogrel data (binary data)
#			        Using library meta (http://cran.r-project.org/web/packages/meta/meta.pdf)
# By Judith Anzures/Steff Lewis
# January 2012

# Update: - Reduce space between columns and add colours
#         - Change resolution 
#         - alter from rosigliazone version to clopidogrel 
#         - change from binary to generic meta analysis
#          
###########################################################################################
# Input
# The input dataset should contain the following variables:
# TE = log RR of treatment effect for each study
# seTE = se of log RR of treatment effect for each study
# studlab = study name
###########################################################################################

remove(list=ls())
setwd("M:/Methodology hub/PSI working group on meta-analysis/graph chapter/R plots") # set working directory
library(grid)
library(meta)

# Read the data
clop.data <- read.csv(file="clopid.csv")
no.studies <- length(clop.data$studlab)

# Perform meta-analysis
clop.meta <- metagen(TE, seTE, studlab,data=clop.data, sm="RR", level=0.95, 
                     comb.fixed=TRUE, comb.random=TRUE, title="", complab="Clopidofrel vs Comparator", 
                     outclab="Risk Ratio", label.e="Clopidogrel", label.c="Comparator")
summary(clop.meta)

# Sort by random effects weight  
ordena <- clop.meta$w.random # random effects weight 

# Plot graph
png(filename = "clop_meta.png", width = 22, height = 35, units="cm", res=300)
forest.meta(clop.meta, sortvar=ordena, xlim=c(0.04,25), rightcols=c("effect", "ci"),
		 xlab="Higher risk for A: *1 or *17   Higher risk for B: *2 to *8 \n Risk ratio and 95% CI",
		 text.fixed="Fixed effect", text.random="Random effects", col.diamond="red2", col.diamond.lines="black",
		 col.square="mediumblue", col.square.lines="black",col.i="mediumblue",plotwidth=unit(8, "cm"))
dev.off()




