###########################################################################################
#
# ssri_funnel ver0.03.r - Funnel plots for the SSRI  data 
#			Using library meta (http://cran.r-project.org/web/packages/meta/meta.pdf)
# By Judith Anzures
# August 2011
#
# Update: - Increase y-axis
#	    - Change to png and increase resolution
#
###########################################################################################
# Input
# The input dataset should contain the following variables:
# mean.e = estimated mean in the experimental group
# sd.e = standard deviation in experimental group
# n.e = experimental group sample size
# mean.c = estimated mean in the control group
# sd.e = standard deviation in control group
# n.c = control group sample size
# studlab = study name
# Drug = categorical variable indicating the type of drug (for subgroup analysis)
###########################################################################################

remove(list=ls())
setwd("U:/Book graphs MA/Funnel plots") # set working directory
library(grid)
library(meta)

# Read the data 
ssri.data <- read.csv(file="ssri_raw_r.csv")

# Using MD
# Perform meta-analysis
ssri.meta_md <- metacont(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
			    data=ssri.data, sm="MD",comb.fixed=TRUE, comb.random=FALSE,
			    label.e="SSRI", label.c="Placebo", byvar=Drug)
summary(ssri.meta_md)

##########################################################################################

# Basic funnel plot
png(filename = "ssri_funnel_basic.png", width=18, height=12, units="cm", res=300)
funnel(ssri.meta_md, xlim=c(-7.5,12.5), bg="red", 
	 xlab="Difference between SSRI and Placebo", ylab="Standard error of difference")
dev.off()

##########################################################################################

# Enhanced funnel plot (including contours and centered at fixed effects estimate)
png(filename = "ssri_funnel_enhance.png", width=18, height=12, units="cm", res=300)
funnel(ssri.meta_md, yaxis="invse", comb.fixed=TRUE,contour=c(0.9, 0.95, 0.99),
	 col.contour=c("seagreen1", "seagreen2", "seagreen3"), level=NULL, xlim=c(-4,10),
	 ref=2.4,lwd=1, cex=1.3, pch=16, studlab=FALSE, cex.studlab=1.25,
	 xlab="Difference between SSRI and Placebo", ylab="1/Standard error of difference",
	 ylim=c(0.195,1.25))
dev.off()


