###########################################################################################
#
# clop_funnel ver0.03.r - Funnel plots for the Clopidogrel  data 
#			Using library meta (http://cran.r-project.org/web/packages/meta/meta.pdf)
# By Judith Anzures/Steff Lewis
# January 2012
#
# Update: - add line at null effect
#         - Change format to png and resolution
#         - change from rosiglitazone to clopidogrel
#         - change from binary to generic meta analysis
#
###########################################################################################
# Input
# The input dataset should contain the following variables:
# TE = log RR of treatment effect for each study
# seTE = se of log RR of treatment effect for each study
# studlab = study name
###########################################################################################

remove(list=ls())
setwd("M:/Methodology hub/PSI working group on meta-analysis/graph chapter/R plots") # set working directory
library(grid)
library(meta)

# Read the data
clop.data <- read.csv(file="clopid.csv")

# Perform meta-analysis
clop.meta <- metagen(TE, seTE, studlab,data=clop.data, sm="RR", level=0.95, 
                     comb.fixed=TRUE, comb.random=TRUE, title="", complab="Clopidofrel vs Comparator", 
                     outclab="Risk Ratio", label.e="Clopidogrel", label.c="Comparator")
summary(clop.meta)


label <- c(rep(" ",24)," ",rep(" ",15)," "," ",rep(" ",6))

# Enhanced funnel plot (including contours and centered at fixed effects estimate)
png(filename = "clop_funnel_enhance.png", width=18, height=12, units="cm", res=300)
funnel(clop.meta, yaxis="se", comb.fixed=FALSE, comb.random=FALSE,contour=c(0.9, 0.95, 0.99),
	 col.contour=c("seagreen1", "seagreen2", "seagreen3"), level=NULL, xlim=c(0.1,10),
	 cex=1.3, pch=16, studlab=label, cex.studlab=0.8,ref=1,lwd=1, 
	 xlab="Risk ratio of *2-*8 to *1 or *17", ylab="Standard error of log risk ratio")
segments(x0=1, y0=2.62, x1=1, y1=0, lty=2, lwd=1)
dev.off()

