###########################################################################################
#
# ssri_meta_reg ver0.02.r - Meta-regression for the SSRI data (continuous data)
#			  Using library meta (http://cran.r-project.org/web/packages/meta/meta.pdf)
# By Judith Anzures
# August 2011
#
# Update: - Change to png format and increase resolution
#
###########################################################################################
# Input
# The input dataset should contain the following variables:
# mean.e = estimated mean in the experimental group
# sd.e = standard deviation in experimental group
# n.e = experimental group sample size
# mean.c = estimated mean in the control group
# sd.e = standard deviation in control group
# n.c = control group sample size
# studlab = study name
# Drug = categorical variable indicating the type of drug 
# baseline.mean = covariate to be used in the meta-regression
###########################################################################################

remove(list=ls())
setwd("U:/Book graphs MA/Meta-regression SSRI") # set working directory
library(grid)
library(meta)
library(lattice)

# Reading the data
ssri.data <- read.csv(file="ssri_raw_r.csv") 

# Perform meta-analysis using mean difference (MD)
ssri.meta_md <- metacont(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
			    data=ssri.data, sm="MD",comb.fixed=FALSE, comb.random=TRUE,
			    label.e="SSRI", label.c="Placebo")
summary(ssri.meta_md)

# Extract weights and treatment effect from random effects meta-analysis 
ssri.data$w.random <- ssri.meta_md$w.random
ssri.data$TE <- ssri.meta_md$TE

# Meta-regression
m.reg <- lm(TE ~ baseline.mean, data=ssri.data, weights=w.random)
summary(m.reg)

# Bubble plot 
attach(ssri.data)
radius <- sqrt(w.random/pi) # to size the circles by area
label <- c(rep(" ",3),"62",rep(" ",31))
png(filename = "ssri_meta_reg.png", width = 18, height = 12, units="cm", res=300)
symbols(baseline.mean, TE, circles=radius, inches=0.1, bg="mediumblue", 
        xlab="Baseline (Hamilton Scale)", ylab="Difference in means (Hamilton Scale)", xlim=c(17,31),
        ) #inches is the scale factor
abline(m.reg, col="red", lwd=2) # Plotting meta-regression line
abline(h=3, lty=3) # Plotting line of clinical significance
text(x=baseline.mean, y=TE, labels=label, cex=1, pos=3)
dev.off()
