###########################################################################################
#
# network_ma ver0.02.r - Rankogram and cumulative plot from a network meta-analysis
#
# By Judith Anzures
# September 2011
#
# Update: - Change format to png and increase resolution
#
###########################################################################################
# Input
# The input dataset should contain a nxn matrix where n is the number of treatments
# in the network meta-analysis, and each column contains the rank probabilities.
# These probabilities can be estimated from a Bayesian hierarchical model using WinBUGs
# (Salanti 2011)
###########################################################################################

remove(list=ls())
setwd("U:/Book graphs MA/Network MA") # set working directory
library(lattice)
library(latticeExtra)
library(reshape)

# Create matrix with probabilities
no.treat <- 5
a.d.no <- c(0.79,0.19,0.02,0,0)
t.a.no <- c(0.19,0.60,0.16,0.05,0)
t.no <- c(0.02,0.18,0.67,0.11,0.02)
a.no <- c(0,0.03,0.15,0.82,0)
p.no <- c(0,0,0,0.02,0.98)
rango <- 1:no.treat
rank.prob <- data.frame(a.d.no, t.a.no, t.no, a.no, p.no) # Dataset with the rank probabilities
cum.prob <- apply(rank.prob,2,cumsum)
rank.prob <- data.frame(rank.prob, rango)
cum.prob <- data.frame(cum.prob, rango)
colnames(rank.prob) <- c("Aspirin+Dipyridamole","Thienopyridines+Aspirin", "Thienopyridines", "Aspirin", 
				  "Placebo", "Rank")
colnames(cum.prob) <- c("Aspirin+Dipyridamole","Thienopyridines+Aspirin", "Thienopyridines", "Aspirin", 
				  "Placebo", "Rank")

# Using trellis plots
layout <- c(no.treat,1)
rank.prob.new <- melt(rank.prob,id="Rank") # Transpose the data for trellis plot
colnames(rank.prob.new) <- c("rank", "treatment", "prob")
prob.plot <- xyplot(rank.prob.new$prob~rank.prob.new$rank|rank.prob.new$treatment, type="l", layout=layout, xlab="Rank", ylab="Probability", 
                    lwd=2,col="mediumblue")

cum.prob.new <- melt(cum.prob, id="Rank") # Transpose the data for trellis plot
colnames(cum.prob.new) <- c("rank", "treatment", "cum.prob")
cum.plot <- xyplot(cum.prob.new$cum.prob~cum.prob.new$rank|cum.prob.new$treatment, type="l", layout=layout, xlab="Rank", ylab="Cumulative probability",
                   lwd=2,col="red")
both.prob <- c(cum.plot, prob.plot, x.same=TRUE, y.same=TRUE, layout=c(no.treat,2))
both.prob2 <- update(both.prob,ylab=c("Cumulative probability" ,"Probability"))

png(file = "network_ma.png", width = 27, height = 18, units="cm", res=300)
print(both.prob2)
dev.off()

