* Graphics for meta analysis - Figure 4.1
* Treatment rankings from a network meta-analysis.
*
* Jeff Tomlinson, November 2011
;

options
    dsoptions="nonote2err"
    ls=150 nocenter missing=' '
    obs=max
;

* Create the treament rankings data set to plot. ;
data trtrnk;
  length trt $40;
  infile datalines delimiter=' ' firstobs=2; 
  input trt $ y1 y2 y3 y4 y5;
datalines;
Treatment                   y1      y2      y3      y4      y5
Aspirin+Dipyridamole       0.79    0.19    0.02    0.00    0.00
Thienopyridines+Aspirin    0.19    0.60    0.16    0.05    0.00
Thienopyridines            0.02    0.18    0.67    0.11    0.02
Aspirin                    0.00    0.03    0.15    0.82    0.00
Placebo                    0.00    0.00    0.00    0.02    0.98
;
run;

title 'Treatment Rank Input Data';
proc print;
run;

* INDS is the name of the input dataset.
*      The format of this dataset is one record per treatment containing the 
*      treatment name and the the probabilities in separate variables.
*
* TRTNAME - The name of the treatment variable in the INDS dataset.
* PVAR - List of variables containing the probabilities in order.  
*        This list must be in a format suitable for use with a datastep array
*        e.g. Y1-Y5 
*             Y1 Y2 Y3 Y4 YLAST
* TITLE - Title for the plot.
* 
;
%let inds=trtrnk;
%let pvar=y1 y2 y3 y4 y5;
%let trtname=trt;
%let plotname=Fig4_1;
%let title=;   
%let footnote=;

* From the input dataset with one record per treatment, create 2 datasets.
* The first dataset _PLOT will contain the data to plot, the format of 
* the _PLOT dataset is changed from wide to narrow, with one record for each
* data point to be plotted for both the probability (PTYPE=1) and cumulative 
* probability (PTYPE=2).  The TRTORD variable is used to reference the treatment
* because it allows the plots to be ordered within the lattice in the order
* they were presented in the input (INDS) dataset.
* The second dataset (_GTRT) is used to create a format (via a CNTLIN form dataset)
* to map TRTORD to the full treatment name given in the input dataset. ;

data _plot(keep=&trtname. x y ptype trtord) 
     _gtrt(keep=trtord trt fmtname type 
           rename=(trt=label trtord=start));
  set &inds.;
    array _y[*] &pvar.;

  retain fmtname 'gtrt' type 'n';
  trtord+1;
  output _gtrt;

  do x=1 to dim(_y);
    ptype = 1;
    y = _y[x];
    output _plot;
    ptype = 2;
    if x gt 1 then _y[x]=_y[x]+_y[x-1];
    y = _y[x];
    output _plot;
  end;
run;

* Create the GTRT format for the treatment (column) labels and 
* the FTYPE format for the row labels. ;
proc format library=work cntlin=_gtrt;
  value ftype
    1 = 'Probability'
    2 = 'Cumulative prob'
  ;
run;

* Modify the STATISTICAL ODS template to have red and blue lines ;
proc template;   
   define style RSTATISTICAL;
      parent=Styles.Statistical;
      style GraphData1 from GraphData1 / LineStyle=1 contrastcolor=red;
      style GraphData2 from GraphData2 / LineStyle=1 contrastcolor=blue;
   end;
run;

* Setup the output PNG filename and size.;
ods listing image_dpi=200 gpath="./" style=rstatistical;
ods graphics / reset
              imagename="&plotname."
              imagefmt=png
              width=9in height=5in
;

title "&title. ";
footnote "&footnote. ";

* PROC SGPANEL to produce the lattice plot.
* TRTORD (1 to N across (columns)) and PTYPE (1, 2 down (rows))
;
proc sgpanel data=_plot  noautolegend;
  panelby trtord ptype/ 
    uniscale=all         %* Use the same scale for all of the cells of the lattice.;
    layout=lattice       %* Use a lattice layout TRTORD for columns, PTYPE for rows.;
    novarname            %* Do not include the variable name in the row/column headings.;
    rowheaderpos=left    %* Row headers to the left.;
    colheaderpos=bottom  %* Column headers at the bottom.;
    onepanel             %* Output the plot as one image. ;
  ;
  series x=x y=y/group=ptype lineattrs=(thickness=2); 
                              %* Plot X and Y from the dataset, with different lines for ;
                              %* Probability and cumulative probability ;
  colaxis display=(nolabel);  %* Do not display a column axis label. ;
  rowaxis display=(nolabel) grid;  %* Add a grid line at each tick mark. ;
                              %* Do not display a row axis label. ;

  format trtord gtrt.    %* Use TRTORD for the ordering, use the GTRT format to supply the treatment label.;
         ptype ftype.    %* Y axis label - Probability top row, Cumulative prob second row. ;
    ;
run;
